==> config-0.1.62.jar: META-INF/leiningen/burningswell/config/project.clj <==
(defproject burningswell/config "0.1.62"
  :description "The Burning Swell configuration"
  :url "https://github.com/burningswell/config"
  :license {:name "Creative Commons Attribution-NonCommercial 3.0"
            :url "http://creativecommons.org/licenses/by-nc/3.0/"}
  :min-lein-version "2.0.0"
  :deploy-repositories [["releases" :clojars]]
  :dependencies [[environ "1.1.0"]
                 [org.clojure/clojure "1.10.0"]
                 [org.clojure/clojurescript "1.10.516" :scope "provided"]]
  :aliases {"ci" ["do"
                  ["difftest"]
                  ["doo" "node" "none" "once"]
                  ["doo" "node" "advanced" "once"]
                  ["lint"]]
            "lint" ["do" ["whitespace-linter"] ["eastwood"]]
            "test-ancient" ["test"]}
  :eastwood {:exclude-linters [:constant-test]}
  :profiles {:dev {:plugins [[jonase/eastwood "0.3.5"]
                             [lein-cljsbuild "1.1.7"]
                             [lein-difftest "2.0.0"]
                             [lein-doo "0.1.11"]
                             [listora/whitespace-linter "0.1.0"]]}
             :repl {:dependencies [[cider/piggieback "0.3.10"]]
                    :repl-options {:nrepl-middleware [cider.piggieback/wrap-cljs-repl]}}}
  :cljsbuild {:builds [{:id "none"
                        :compiler
                        {:main burningswell.config.test-runner
                         :optimizations :none
                         :output-dir "target/none"
                         :output-to "target/none-test.js"
                         :target :nodejs}
                        :source-paths ["src" "test"]}
                       {:id "advanced"
                        :compiler
                        {:main burningswell.config.test-runner
                         :optimizations :advanced
                         :output-dir "target/advanced"
                         :output-to "target/advanced-test.js"
                         :target :nodejs}
                        :source-paths ["src" "test"]}]})

==> config-0.1.63.jar: META-INF/leiningen/burningswell/config/project.clj <==
(defproject burningswell/config "0.1.63"
  :description "The Burning Swell configuration"
  :url "https://github.com/burningswell/config"
  :license {:name "Creative Commons Attribution-NonCommercial 3.0"
            :url "http://creativecommons.org/licenses/by-nc/3.0/"}
  :min-lein-version "2.0.0"
  :deploy-repositories [["releases" :clojars]]
  :dependencies [[environ "1.1.0"]
                 [org.clojure/clojure "1.10.0"]
                 [org.clojure/clojurescript "1.10.520" :scope "provided"]]
  :aliases {"ci" ["do"
                  ["difftest"]
                  ["doo" "node" "none" "once"]
                  ["doo" "node" "advanced" "once"]
                  ["lint"]]
            "lint" ["do" ["whitespace-linter"] ["eastwood"]]
            "test-ancient" ["test"]}
  :eastwood {:exclude-linters [:constant-test]}
  :profiles {:dev {:plugins [[jonase/eastwood "0.3.5"]
                             [lein-cljsbuild "1.1.7"]
                             [lein-difftest "2.0.0"]
                             [lein-doo "0.1.11"]
                             [listora/whitespace-linter "0.1.0"]]}}
  :cljsbuild {:builds [{:id "none"
                        :compiler
                        {:main burningswell.config.test-runner
                         :optimizations :none
                         :output-dir "target/none"
                         :output-to "target/none-test.js"
                         :target :nodejs}
                        :source-paths ["src" "test"]}
                       {:id "advanced"
                        :compiler
                        {:main burningswell.config.test-runner
                         :optimizations :advanced
                         :output-dir "target/advanced"
                         :output-to "target/advanced-test.js"
                         :target :nodejs}
                        :source-paths ["src" "test"]}]})
